# RawElement

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**uuid** | **str** |  | 
**type** | **str** |  | 
**attributes** | **int** |  | [optional] 
**material_list** | **list[int]** |  | [optional] 
**psets** | **list[int]** |  | [optional] 
**classifications** | **list[int]** |  | [optional] 
**layers** | **list[int]** |  | [optional] 
**systems** | **list[int]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


